/***************************************************************************
*   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#include "canvas.h"

#include <iostream>

#include <cstdlib>
#include <math.h>

#include <assert.h>

namespace Papyrus
{

Canvas::Canvas( double w, double h ):
m_width(w), m_height(h)
  {
  }

  Canvas::~Canvas()
  {}

  Canvas::pointer Canvas::create( double w, double h )
  {
    return Canvas::pointer( new Canvas( w, h ) );
  }

  void Canvas::set_background( Cairo::RefPtr<Cairo::Pattern> background )
  {
    m_background = background;
  }

  Cairo::RefPtr<Cairo::Pattern> Canvas::get_background()
  {
    return m_background;
  }

  void Canvas::draw( Cairo::RefPtr<Cairo::Context> cairo )
  {
    cairo->save();
    if ( m_background ) {
      cairo->set_source( m_background );
      cairo->paint();
    }
    cairo->restore();
    Group::draw( cairo );
  }

  sigc::signal<void> Canvas::signal_size()
  {
    return m_signal_size;
  }

  double Canvas::size_w( )
  {
    return m_width;
  }

  double Canvas::size_h( )
  {
    return m_height;
  }

  void Canvas::size( double & w, double & h )
  {
    w = m_width;
    h = m_height;
  }

  void Canvas::set_size_w( double w )
  {
    m_width = w;
    m_signal_size.emit();
  }

  void Canvas::set_size_h( double h )
  {
    m_height = h;
    m_signal_size.emit();
  }

  void Canvas::set_size( double w, double h )
  {
    m_width = w;
    m_height = h;
    m_signal_size.emit();
  }

}
