/***************************************************************************
 *   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#ifndef PAPYRUSCIRCLE_H
#define PAPYRUSCIRCLE_H

#include <papyrus/arc.h>

/**
 * \page guide_circle Circles
 * A circle is drawn centered on the x,y coordinate with a specified radius.
 *
 * The following contains an example that will add a green circle with a black
 * border to a canvas. The blue lines represent the
 * x and y axes, and show through since an alpha value of 0.9 is used.
 *
 * \image html circle.png "Circle drawn by example code below"
 *
 * \dontinclude factory.cpp
 * \skip example_circle
 * \until }
 *
 */

namespace Papyrus
{

  /**
   * A circle is drawn centered on the x,y coordinate with a specified radius.
   *
   * The circle class is a very thin interface for a 360' arc, and doesn't actually extend
   * the arc in any meaningful way, but is provided for convenience and notation.
   *
   * \image html circle.png "Circle"
   *
   * @author Rick L Vinyard Jr
   */
  class Circle : public Arc
  {
    protected:

      Circle( double radius, Cairo::RefPtr<Cairo::Pattern> fill );

      Circle( double radius,
              Cairo::RefPtr<Cairo::Pattern> fill,
              const LineStyle& outline
            );

    public:
      typedef PapyrusSmartPointer<Circle> pointer;

      /** Creates a circle with the specified radius */
      static Circle::pointer create( double radius = 1.0,
                                     Cairo::RefPtr<Cairo::Pattern> fill = Cairo::RefPtr<Cairo::Pattern>()
                                   );

      /** Creates a circle with the specified radius */
      static Circle::pointer create( double radius,
                                     Cairo::RefPtr<Cairo::Pattern> fill,
                                     const LineStyle& outline
                                   );

      ~Circle();

      PAPYRUS_CLASS_NAME( "Circle" );

      PAPYRUS_CLONE_METHOD( Circle );

  };

}

#endif
