/***************************************************************************
 *   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Lesser General Public License as        *
 *   published by the Free Software Foundation version 2.1.                *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
 ***************************************************************************/
#ifndef PAPYRUSENUMS_H
#define PAPYRUSENUMS_H

namespace Papyrus
{

  /**
   * The selection mode determines what events trigger an attempt
   * to select an object in the canvas.
   *
   * The values have been selected to allow multiple events to trigger
   * a selection.
   */
  typedef enum SelectionMode {
    SELECT_PRESS = 1 << 0,   /**< Selection occurs when a button is pressed */
    SELECT_RELEASE = 1 << 1,   /**< Selection occurs when a button is released */
    SELECT_FOLLOW = 1 << 2,   /**< Selection follows the mouse */
  } SelectionMode;

  typedef enum AffineTransform {
    TRANSLATE_X = 1 << 0,
    TRANSLATE_Y = 1 << 1,
    SCALE_X = 1 << 2,
    SCALE_Y = 1 << 3,
    ROTATE = 1 << 4,
    SKEW_X = 1 << 5,
    SKEW_Y = 1 << 6,
  } AffineTransform;

  enum {
    FILL = 1<<0,
    OUTLINE = 1<<1
  };

  typedef enum Side {
    TOP = 1<<0,
    RIGHT = 1<<1,
    BOTTOM = 1<<2,
    LEFT = 1<<3,
  } Side;

  typedef enum Position {
    START_POSITION,
    TOP_CENTER=START_POSITION,
    TOP_RIGHT,
    CENTER_RIGHT,
    BOTTOM_RIGHT,
    BOTTOM_CENTER,
    BOTTOM_LEFT,
    CENTER_LEFT,
    TOP_LEFT,
    END_POSITION,
  } Position;

  typedef enum Axis {
    X_AXIS = 1<<0,
    Y_AXIS = 1<<1,
  } Axis;

  typedef enum Handles {
    NO_HANDLES = 0,
    CORNER_HANDLES = 1<<0,
    ALL_HANDLES = 1<<1,
  } Handles;

}

#endif
