/***************************************************************************
*   Copyright (C) 2006 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#include "rgba.h"
#include "color_utility.h"
#include "x11_color.h"

#include <stdexcept>


namespace Papyrus
  {

  RGBA::RGBA(double r, double g, double b, double a):
      red(r),
      green(g),
      blue(b),
      alpha(a)
  { }

  RGBA::RGBA(const std::string& name, double a)
  {
    *this = x11_color( name );
    this->alpha = a;
  }

  double RGBA::operator[](unsigned index)
  {
    switch (index)
      {
      case 0:
        return red;
      case 1:
        return green;
      case 2:
        return blue;
      case 3:
        return alpha;
      default:
        throw std::out_of_range("Papyrus::RGB Only indexes 0-3 are valid.");
      }
  }

  RGBA::operator Cairo::RefPtr<Cairo::Pattern>()
  {
    return Cairo::SolidPattern::create_rgba(this->red,
                                            this->green,
                                            this->blue,
                                            this->alpha );
  }

}
