/***************************************************************************
*   Copyright (C) 2004 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#ifndef PAPYRUSGTKVIEWPORT_H
#define PAPYRUSGTKVIEWPORT_H

#include <set>

#include <gtkmm.h>

#include <papyrus/canvas.h>
#include <papyrus/controller.h>
#include <papyrusmm/enums.h>

namespace PapyrusGtk {

/**
@author Rick L Vinyard Jr
*/
class Viewport: public Gtk::EventBox {

public:
  Viewport();
  virtual ~Viewport();


public:
  typedef std::set<Papyrus::Controller::pointer> Controllers;

  // Drawing Operations
  virtual void clear();

  /** Get the root canvas object */
  Papyrus::Canvas::pointer canvas();

  /** Set the root canvas object */
  void set_canvas( Papyrus::Canvas::pointer  canvas );

  void set_scroll_point(SCROLL_TO scroll_to=SCROLL_TO_CENTER);

  SCROLL_TO scroll_point();

  void scroll_offsets(double& x, double& y) const;

  void scroll_to(double offset_x, double offset_y);

  void scroll_to_center();

  /**
   * Convert window coordinates to canvas coordinates.
   * \param[in] winx The window x coordinate
   * \param[in] winy The window y coordinate
   * \param[out] canvasx The canvas x coordinate relating to (winx, winy)
   * \param[out] canvasy The canvas y coordinate relating to (winx, winy)
   */
  void window_to_canvas(double winx, double winy, double& canvasx, double& canvasy) const;

  /**
   * Convert canvas coordinates to window coordinates.
   * \param[in] canvasx The canvas x coordinate
   * \param[in] canvasy The canvas y coordinate
   * \param[out] winx The window x coordinate relating to (canvasx, canvasy)
   * \param[out] winy The window y coordinate relating to (canvasx, canvasy)
   */
  void canvas_to_window(double canvasx, double canvasy, double& winx, double& winy) const;

  const Controllers& controllers();

  void add_controller( Papyrus::Controller::pointer controller );

  void remove_controller( Papyrus::Controller::pointer controller );

  bool canvas_size_tied_to_viewport();

  void tie_canvas_size_to_viewport(bool tie=true);

  bool viewport_size_tied_to_canvas();

  void tie_viewport_size_to_canvas(bool tie=true);

protected:
  Papyrus::Canvas::pointer m_canvas;
  Papyrus::Group::pointer m_root;
  int m_width, m_height;
  double m_scroll_x, m_scroll_y;
  bool m_tie_canvas_size_to_viewport, m_tie_viewport_size_to_canvas;
  Controllers m_controllers;
  sigc::connection m_canvas_redraw_connection;
  sigc::connection m_canvas_size_connection;
  SCROLL_TO m_scroll_to;
  Cairo::RefPtr<Cairo::Context> m_context;

  void on_canvas_size_changed();

  void on_need_redraw(double x, double y, double w, double h);

  bool expose_event_callback(GdkEventExpose* e);

  void size_allocate_callback(Gtk::Allocation& allocation);

  bool button_press_event_callback( GdkEventButton* event );

  bool button_release_event_callback( GdkEventButton* event );

  bool key_press_event_callback( GdkEventKey* event );

  bool key_release_event_callback( GdkEventKey* event );

  bool motion_notify_event_callback( GdkEventMotion* event );

  bool scroll_event_callback( GdkEventScroll* event );

}; // class Viewport

}

#endif
